# We use the three package below. Uncomment the line below to install those packages.
# install.packages("tidyverse", "ggpubr", "likert")
library(tidyverse)
library(ggpubr)
library(likert)

# ----------------------------------------------------------------------------
# Imports the CSV file with dialogue and survey data. For the dialogues, 
#.  convert the coded stages into the labels of 
#.  the software development life cycle (SDLC)
raw_dialogues <- read.csv2("data/filtered_dialog_data.csv") %>% 
  mutate(SDLC = factor(cycle, levels=seq(0,5), labels=c("Unspecified", "Planning and Analysis", 
                                          "Planning and Analysis", "Design",
                                          "Implementation", "Testing")))

raw_surveys <- read.csv2("data/filtered_survey_data.csv")

# ----------------------------------------------------------------------------
# Part 1 - Tables 2 and 3 from the paper for statistics on the dialogue types.
table2 <- raw_dialogues %>% 
  group_by(dialogue_type) %>% 
  summarise(Interactions = n(), Participants = n_distinct(id),
            AvgLength = round(mean(length),2), SD = round(sd(length),2))

table3 <- raw_dialogues %>% 
  group_by(dialogue_type, SDLC) %>% 
  tally(name = "Count") %>% 
  spread(key = SDLC, value = Count)


# ----------------------------------------------------------------------------
# Part 2 - Figures from the paper.
# Load only the survey Likert answers. Used to create the Diverging plot.
# Rename CSV column names with the actual questions' text
surv_likert_df <- raw_surveys %>% select(3:7)
names(surv_likert_df) <- c("Reducing repetitive tasks", "Staying more focused", 
                           "Initiating discussions with teammates",
                           "Making better decisions", "Learning new concepts")


# Creates a likert "object" and create the Diverging plot (Fig. 5)
#   then adds the correct labels and colors to the diverging plot.
surv_result = likert(surv_likert_df, nlevels = 6)
diverging_plot <- plot(surv_result, type="bar") +
  labs(title = "How helpful was ChatGPT in the following:\n", fill = "") +
  scale_fill_brewer(palette = "PuOr",
                    labels=c("1"="Not helpful at all", "2" = "Slightly helpful",
                             "3" = "Moderately helpful", "4" ="Helpful",
                             "5" = "Very helpful", "6" = "Extremely helpful")) +
  theme(legend.position = "bottom")

# Creates the dataframe only with results on trust to show the proportion of
#.  trust among participants. YMax and YMin are needed for the circular shape.
trust_df <- raw_surveys %>% select(trust) %>% 
  group_by(trust) %>% 
  tally(name = "Count") %>% 
  mutate(Trust = factor(trust, levels = seq(1,6)),
         Perc  = round(100*Count/sum(Count),1),
         Ymax  = cumsum(Perc),
         Ymin  = c(0, head(Ymax, n=-1)))

# Creates the doughnut plot with the different percentage for answers on trust.
doughtnut_size <- 2 # variable to define the width of the doughnut plot
trust_plot <- ggplot(trust_df, aes(x = doughtnut_size, y = Perc, fill = Trust)) +
  geom_col(width = 0.7, color = "white", linewidth = 2) +
  geom_text(aes(label=paste(Perc,"%")), position = position_stack(vjust = 0.5), 
            size=3, fontface = "bold") +
  scale_fill_brewer(palette = "PuOr", drop = FALSE,
                    labels=c("1" = "No Trust", "2" = "Low Trust", 
                             "3" = "Little Trust", "4" = "Moderate Trust", 
                             "5" = "Some Trust", "6" = "Complete Trust")) +
  labs(fill = "", title = "How much did you trust ChatGPT's answers?") +
  coord_polar(theta="y") +
  xlim(c(0, doughtnut_size + 0.5)) +
  theme_void() + theme(legend.position = "bottom")


# Combines both plots into a single figure and saves it as a PDF (Fig. 5)
fig5_plot <- ggarrange(diverging_plot, trust_plot, ncol = 2)
ggsave(fig5_plot, filename = "figs/SurveyResults.pdf", device = "pdf", width = 34, height = 12, units = "cm")